@@ -483,85 +483,6 @@ class TestDataGetAllExceptUserId(MongoIntegrationBaseTestCase):
         )
 
 
-class TestExecuteQuery(MongoIntegrationTransactionTestCase):
-
-    fixture = access_control_data_fixture
-
-    def test_execute_query_data_ordering(self):
-        # Arrange
-        query = {}
-        ascending_order_by_field = ["+title"]
-        descending_order_by_field = ["-title"]
-        # Act
-        ascending_result = UserMetadata.execute_query(query, ascending_order_by_field)
-        descending_result = UserMetadata.execute_query(query, descending_order_by_field)
-        # Assert
-        for i in range(len(ascending_result)):
-            self.assertTrue(
-                ascending_result.all()[i].title
-                == descending_result.all()[len(ascending_result) - i - 1].title
-            )
-
-    def test_execute_query_data_ascending_sorting(self):
-        # Arrange
-        ascending_order_by_field = ["+title"]
-        query = {}
-        # Act
-        ascending_result = UserMetadata.execute_query(query, ascending_order_by_field)
-        # Assert
-        self.assertTrue(self.fixture.data_1.title == ascending_result.all()[0].title)
-        self.assertTrue(self.fixture.data_2.title == ascending_result.all()[1].title)
-
-    def test_execute_query_data_descending_sorting(self):
-        # Arrange
-        descending_order_by_field = ["-title"]
-        query = {}
-        # Act
-        descending_result = UserMetadata.execute_query(query, descending_order_by_field)
-        # Assert
-        self.assertTrue(
-            self.fixture.data_2.title
-            == descending_result.all()[len(descending_result) - 2].title
-        )
-        self.assertTrue(
-            self.fixture.data_1.title
-            == descending_result.all()[len(descending_result) - 1].title
-        )
-
-    def test_execute_query_multi_field_sorting(self):
-        # Arrange
-        ascending_order_by_multi_field = ["+title", "+user_id"]
-        descending_order_by_multi_field = ["+title", "-user_id"]
-        query = {}
-        # Act
-        ascending_result = UserMetadata.execute_query(
-            query, ascending_order_by_multi_field
-        )
-        descending_result = UserMetadata.execute_query(
-            query, descending_order_by_multi_field
-        )
-        # Assert
-        self.assertEqual(self.fixture.data_4.user_id, ascending_result.all()[4].user_id)
-        self.assertEqual(self.fixture.data_5.user_id, ascending_result.all()[3].user_id)
-
-        self.assertEqual(
-            self.fixture.data_4.user_id, descending_result.all()[3].user_id
-        )
-        self.assertEqual(
-            self.fixture.data_5.user_id, descending_result.all()[4].user_id
-        )
-
-    def test_data_execute_query_api_without_sorting_param_use_default_data_sorting_setting(
-        self,
-    ):
-        # Arrange
-        mock_user = _create_user("1", is_superuser=True)
-        # Act
-        UserMetadata = user_metadata_api.execute_query({}, mock_user)
-        # Assert
-        self.assertListEqual(list(UserMetadata), self.fixture.data_collection)
-
-
 class TestGetAllByWorkspace(MongoIntegrationBaseTestCase):
 
     fixture = access_control_data_fixture
